
#ifndef _C15_kl749_
#define _C15_kl749_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_CHARACTER_8 F69_964(EIF_REFERENCE);
extern void F69_966(EIF_REFERENCE, EIF_CHARACTER_8);
extern void EIF_Minit749(void);
extern long O966[];

#ifdef __cplusplus
}
#endif

#endif
